Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6787)

Unified Diff: chrome/browser/profile_import_process_host.h

Issue 2885017: Moved common parts of ChildProcessHost into chrome/common and created a Brows... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: Code review changes Created 10 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/plugin_service.cc ('k') | chrome/browser/profile_import_process_host.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/profile_import_process_host.h
===================================================================
--- chrome/browser/profile_import_process_host.h (revision 51385)
+++ chrome/browser/profile_import_process_host.h (working copy)
@@ -12,7 +12,7 @@
#include "base/ref_counted.h"
#include "base/task.h"
#include "base/values.h"
-#include "chrome/browser/child_process_host.h"
+#include "chrome/browser/browser_child_process_host.h"
#include "chrome/browser/chrome_thread.h"
#include "chrome/browser/history/history_types.h"
#include "chrome/browser/importer/importer_data_types.h"
@@ -26,7 +26,7 @@
// Browser-side host to a profile import process. This class lives only on
// the IO thread. It passes messages back to the |thread_id_| thread through
// a client object.
-class ProfileImportProcessHost : public ChildProcessHost {
+class ProfileImportProcessHost : public BrowserChildProcessHost {
public:
// An interface that must be implemented by consumers of the profile import
@@ -87,8 +87,8 @@
DISALLOW_COPY_AND_ASSIGN(ImportProcessClient);
};
// |resource_dispatcher| is used in the base ChildProcessHost class to manage
// IPC requests.
// |import_process_client| implements callbacks which are triggered by
// incoming IPC messages. This client creates an interface between IPC
// messages received by the ProfileImportProcessHost and the internal
@@ -124,7 +124,7 @@
// ImportProcessClient.
void OnMessageReceived(const IPC::Message& message);
// Overridden from ChildProcessHost:
virtual void OnProcessCrashed();
virtual bool CanShutdown() { return true; }
virtual URLRequestContext* GetRequestContext(
@@ -87,8 +87,8 @@
DISALLOW_COPY_AND_ASSIGN(ImportProcessClient);
};
- // |resource_dispatcher| is used in the base ChildProcessHost class to manage
- // IPC requests.
+ // |resource_dispatcher| is used in the base BrowserChildProcessHost class to
+ // manage IPC requests.
// |import_process_client| implements callbacks which are triggered by
// incoming IPC messages. This client creates an interface between IPC
@@ -124,7 +124,7 @@
// ImportProcessClient.
void OnMessageReceived(const IPC::Message& message);
- // Overridden from ChildProcessHost:
+ // Overridden from BrowserChildProcessHost:
virtual void OnProcessCrashed();
virtual bool CanShutdown() { return true; }
« no previous file with comments | « chrome/browser/plugin_service.cc ('k') | chrome/browser/profile_import_process_host.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698